Enum zng_layout::unit::LengthExpr
source · pub enum LengthExpr {
Add(Length, Length),
Sub(Length, Length),
Mul(Length, Factor),
Div(Length, Factor),
Max(Length, Length),
Min(Length, Length),
Abs(Length),
Neg(Length),
Lerp(Length, Length, Factor),
}Expand description
Represents an unresolved Length expression.
Variants
Add(Length, Length)
Sums the both layout length.
Sub(Length, Length)
Subtracts the first layout length from the second.
Mul(Length, Factor)
Multiplies the layout length by the factor.
Div(Length, Factor)
Divide the layout length by the factor.
Max(Length, Length)
Maximum layout length.
Min(Length, Length)
Minimum layout length.
Abs(Length)
Computes the absolute layout length.
Neg(Length)
Negate the layout length.
Lerp(Length, Length, Factor)
Linear interpolate between lengths by factor.
Implementations
sourceimpl LengthExpr
impl LengthExpr
sourcepub fn memory_used(&self) -> ByteLength
pub fn memory_used(&self) -> ByteLength
Gets the total memory allocated by this length expression.
This includes the sum of all nested Length::Expr heap memory.
sourcepub fn to_length_checked(self) -> Length
pub fn to_length_checked(self) -> Length
Convert to Length::Expr, logs warning for memory use above 1kB, logs error for use > 20kB and collapses to Length::zero.
Every length expression created using the std::ops uses this method to check the constructed expression. Some operations
like iterator fold can cause an expression explosion where two lengths of different units that cannot
be evaluated immediately start an expression that subsequently is wrapped in a new expression for each operation done on it.